@@ -1,18 +1,18 @@
 # The EMbC Package for R
-# 
+#
 # Copyright 2013, 2014, 2015 Joan Garriga <jgarriga@ceab.csic.es>, Aitana Oltra
 # <aoltra@ceab.csic.es>, John R.B. Palmer <johnrbpalmer@gmail.com>, Frederic
 # Bartumeus <fbartu@ceab.csic.es>
-# 
+#
 # EMbC is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software
 # Foundation, either version 3 of the License, or  (at your option) any later
 # version.
-# 
+#
 # EMbC is distributed in the hope that it will be useful, but WITHOUT ANY
 # WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 # A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License along with
 # this program.  If not, see http://www.gnu.org/licenses.
 
@@ -20,19 +20,19 @@
 # -----------------------
 
 #' @title Select a single path from a \code{binClstStck} instance.
-#'   
+#'
 #' @description \code{slct} selects a single path from a \code{binClstStck}
 #'   instance.
-#'   
+#'
 #' @param stck A \code{binClstStck} instance.
-#'   
+#'
 #' @param pathNmbr The number of the single path to be selected.
-#'   
+#'
 #' @return Returns the single \link{binClstPath_instance} selected.
-#'   
+#'
 #' @export
 #' @rdname slct
-#'   
+#'
 #' @examples
 #' \dontrun{
 #' # -- select path number 3 in mybcpstack --
@@ -47,19 +47,19 @@ slct <- function(stck,pathNmbr){
 	}
 
 #' @title Sets binClst color palette .
-#'   
+#'
 #' @description \code{setc} sets the color palette to a color family from the
 #'   RColorbrewer package
-#'   
+#'
 #' @param bC A \link{binClst_instance}.
-#'   
+#'
 #' @param fam The name of a color family from the Rcolorbrewer R-package,
 #'   (default color palette is 'RdYlBu' which is colorblind safe and print
 #'   friendly up to 6 colors).
-#'   
+#'
 #' @export
 #' @rdname setc
-#'   
+#'
 #' @examples
 #' # -- change the color palette of mybc to "PuOr" --
 #' \dontrun{
@@ -71,24 +71,24 @@ setc <- function(bC,fam='RdYlBu'){
 	bC@C <- getColors(bC@k,fam)
 	assign(objName,bC,envir=parent.frame())}
 
-# binClst Methods 
+# binClst Methods
 # ---------------
 
 #' @title Likelihood profile plots
-#'   
+#'
 #' @description \code{lkhp} likelihood optimization plot.
-#'   
+#'
 #' @param obj A \code{BinClst_instance} or a list of them.
-#'   
+#'
 #' @param offSet A numeric value indicating an offset to avoid the initial
 #'   iterations. This is usefull to see the likelihood evolution in the last
 #'   iterations where the changes in likelihood are of different order of
 #'   magnitud than those at the starting iterations.
-#'   
+#'
 #' @export
 #' @rdname lkhp
-#'   
-#' @examples 
+#'
+#' @examples
 #' # -- apply EMbC to the example path --
 #' mybcp <- stbc(expth)
 #' # -- inspect the likelihood evolution --
@@ -123,26 +123,26 @@ setMethod("lkhp",signature(obj="list"),function(obj,offSet){
 	})
 
 #' @title Clustering statistics.
-#'   
+#'
 #' @description \code{stts} clustering statistics information.
-#'   
+#'
 #' @param obj Either a \link{binClst_instance} or a \code{binClstStck} instance.
 #'   In the latter case statistics are given at stack level.
-#'   
+#'
 #' @param dec The number of decimals for mean/stdv formatting.
 #' @param width The number of digits for mean/stdv formatting.
-#'   
+#'
 #' @details
-#' 
+#'
 #' This method prints a line for each cluster with the following information:
 #' the cluster number, the cluster binary label, the cluster mean and variance
 #' of each input feature (two columns for each variable), and the size of the
 #' cluster in number and proportion of points (the posterior marginal
 #' distribution).
-#' 
+#'
 #' @export
 #' @rdname stts
-#'   
+#'
 #' @examples
 #' # -- apply EMbC to the example path with solar covariate 'height'--
 #' mybcp <- stbc(expth,scv='height',info=-1)
@@ -179,34 +179,36 @@ setMethod("stts",signature(obj="binClstStck"),function(obj,dec,width){
 	})
 
 #' @title Clustering 2D-scatterplot
-#'   
+#'
 #' @description \code{sctr} generates a scatterplot from a
 #'   \link{binClst_instance}, showing clusters in different colors.
-#'   
+#'
 #' @param obj A \link{binClst_instance}.
-#'   
+#'
 #' @param ref
-#'   
+#'
 #'   A numeric vector with expert/reference labelling for visual validation of
 #'   the clustering.
-#'   
+#'
 #'   A second \link{binClst_instance} to be compared with the former.
-#'   
+#'
 #' @param showVars When the number of variables is greater than two, a length 3
 #'   numeric vector indicating one splitting variable and two variables to be
 #'   scattered (given in that order).
-#'   
+#'
 #' @param showClst When the number of variables is greater than two, a numeric
 #'   vector (of variable length) indicating a subset of the clusters that will
 #'   be shown in the scatter plot. This is usefull in case of overlapping
 #'   clusters.
-#'   
+#'
+#' @param bg A valid colour especification to be used as background colour for multivariate scatterplots. By default a light-grey colour is used to enhance data points visibility.
+#'
 #' @param ... Parameters \code{ref}, \code{showVars} and \code{showClst} are
 #'   optional.
-#'   
+#'
 #' @export
 #' @rdname sctr
-#'   
+#'
 #' @examples
 #' # -- apply EMbC to the example path --
 #' mybcp <- stbc(expth,info=-1)
@@ -216,8 +218,8 @@ setMethod("stts",signature(obj="binClstStck"),function(obj,dec,width){
 setGeneric("sctr",function(obj,...){standardGeneric("sctr")})
 
 #' @rdname sctr
-setMethod("sctr",signature(obj="binClst"),function(obj,ref=NULL,showVars=NULL,showClst=NULL,...){
-	if (!is.null(ref)){			
+setMethod("sctr",signature(obj="binClst"),function(obj,ref=NULL,showVars=NULL,showClst=NULL, bg=NULL, ...){
+	if (!is.null(ref)){
 		if (class(ref) == 'numeric'){
 			bCX <- obj
 			bCX@A <- ref
@@ -226,22 +228,24 @@ setMethod("sctr",signature(obj="binClst"),function(obj,ref=NULL,showVars=NULL,sh
 			bCX <- ref
 			}
 		if (obj@m==2){
-			parDef <- parSet(mtx=matrix(c(1,2),2,1,byrow=TRUE),widths=c(1,1,0.5))
+			parDef <- parSet(mtx=matrix(c(1,2),2,1,byrow=TRUE), widths=c(1,1,0.5))
 			sctr2D(obj)
 			sctr2D(bCX)
 			}
 		else{
-			parDef <- parSet(mtx=matrix(c(1,2,3),1,3,byrow=TRUE),widths=c(1,1,0.5),bg=brewer.pal(8,'Greys')[4],oma=c(4,1,4,1))
+			if (is.null(bg)) bg <- brewer.pal(8,'Greys')[1]
+			parDef <- parSet(mtx=matrix(c(1,2,3),1,3,byrow=TRUE), widths=c(1,1,0.5), bg=bg, oma=c(4,1,4,1))
 			sctr3D(bCX,showVars,showClst)
 			}
-		}		
+		}
 	else{
 		if (obj@m==2){
 			parDef <- parSet()
 			sctr2D(obj)
 			}
 		else{
-			parDef <- parSet(mtx=matrix(c(1,2,3),1,3,byrow=TRUE),widths=c(1,1,0.5),bg=brewer.pal(8,'Greys')[4],oma=c(4,1,4,1))
+			if (is.null(bg)) bg <- brewer.pal(8,'Greys')[1]
+			parDef <- parSet(mtx=matrix(c(1,2,3),1,3,byrow=TRUE),widths=c(1,1,0.5), bg=bg, oma=c(4,1,4,1))
 			sctr3D(obj,showVars,showClst)
 			}
 		}
@@ -254,18 +258,18 @@ setMethod("sctr",signature(obj="binClstStck"),function(obj,ref=NULL,showVars=NUL
 	})
 
 #' @title Dynamic 3D-scatterplot
-#'   
+#'
 #' @description \code{sct3} generates a dynamic 3D-scatterplot of a multivariate
 #'   \link{binClst_instance}, showing clusters in different colors. The scatter
 #'   plot can be zoomed/rotated with the mouse.
-#'   
+#'
 #' @inheritParams sctr
-#'   
+#'
 #' @details This function needs the package "rgl" to be installed.
-#'   
+#'
 #' @export
 #' @rdname sct3
-#'   
+#'
 #' @examples
 #' \dontrun{
 #' # -- apply EMbC to the example path with scv='height' --
@@ -294,7 +298,7 @@ setMethod("sct3",signature(obj="binClst"),function(obj,showVars=NULL,showClst=NU
 		X <- X[which(A %in% showClst),]
 		A <- A[which(A %in% showClst)]}
 	# 3d scatterplot
-	parDef <- parSet(bg=brewer.pal(4,'Greys')[4])			 		
+	parDef <- parSet(bg=brewer.pal(4,'Greys')[4])
 	rgl::bg3d(brewer.pal(8,'Greys')[4])
 #~ 	rgl::par3d('font'=3,'cex'=0.7) # works only on windows !!!
 	rgl::par3d('family'='bitmap','font'=1,'cex'=1)
@@ -304,25 +308,25 @@ setMethod("sct3",signature(obj="binClst"),function(obj,showVars=NULL,showClst=NU
 	})
 
 #' @title Labeling profile plot
-#'   
+#'
 #' @description \code{lblp} plots the labeling profile of a
 #'   \link{binClst_instance}.
-#'   
+#'
 #' @param obj A \link{binClst_instance}.
-#'   
+#'
 #' @param ref
-#'   
+#'
 #'   A numeric vector with an expert's labelling profile.
-#'   
+#'
 #'   A second \link{binClst_instance} to be compared with the first.
-#'   
+#'
 #' @param lims A numeric vector with lower and upper bounds to limit the plot.
-#'   
+#'
 #' @param ... Parameters \code{ref} and \code{lims} are optional.
-#'   
+#'
 #' @export
 #' @rdname lblp
-#'   
+#'
 #' @examples
 #' # -- apply EMbC to the example path --
 #' mybcp <- stbc(expth)
@@ -375,34 +379,34 @@ setMethod("lblp",signature(obj="binClst",ref="binClst"),function(obj,ref,lims=NU
 	})
 
 #' @title Check labeling profile
-#'   
+#'
 #' @description Plots the labeling profile of a
 #'   \link{binClst_instance} against a control variable (e.g. environmental
 #'   information) depicted as background coloured bars.
-#'   
+#'
 #' @param obj A \link{binClst_instance}.
-#'   
+#'
 #' @param ctrlLbls A numeric vector with the control labels or a string
 #'   specifying one of 'height', 'azimuth' or 'both' solar covarites. By
 #'   default, for a \link{binClstPath_instance} it is set to the solar height
 #'   covariate, regardless it has been used or not for the clustering.
-#'   
+#'
 #' @param ctrlClrs A vector of colors to depict the control labelling. At least
 #'   one colour should be specified for each different control label. By default
 #'   white/grey colours are used for the default control labels.
-#'   
+#'
 #' @param ctrlLgnd A vector of strings identifying the labels for the legend of
 #'   the plot. They are automatically generated for the solar covariates.
-#'   
+#'
 #' @param lims A numeric vector with lower and upper bounds to limit the plot.
-#'   
+#'
 #' @param ... Parameters \code{ctrLbls}, \code{ctrlClrs}, \code{ctrlLgnd} and
 #'   \code{lims} are optional.
-#'   
+#'
 #' @export
 #' @docType methods
 #' @rdname chkp
-#'   
+#'
 #' @examples
 #' # -- apply EMbC to \code{expth} --
 #' mybcp <- stbc(expth)
@@ -462,27 +466,27 @@ setMethod("chkp",signature(obj="binClst"),function(obj,ctrlLbls=NULL,ctrlClrs=NU
 	})
 
 #' @title Confusion matrix
-#'   
+#'
 #' @description \code{cnfm} computes the confusion matrix of the clustering with
 #'   respect to an expert/reference labelling of the data. Also, it can be used
 #'   to compare the labellings of two different clusterings of the same
 #'   trajectory, (see details).
-#'   
+#'
 #' @param obj A \link{binClst_instance} or \code{bnClstStck} instance.
-#'   
+#'
 #' @param ref
-#'   
+#'
 #'   A numeric vector with an expert/reference labelling of the data.
-#'   
+#'
 #'   A second \link{binClst_instance} (see details).
-#'   
+#'
 #' @param ret A boolean value (defaults to FALSE). If ret=TRUE the confusion
 #'   matrix is returned as a matrix object.
-#'   
+#'
 #' @param ... Parameters \code{ref} and \code{ret} are optional.
-#'   
+#'
 #' @details
-#' 
+#'
 #' The confusion matrix yields marginal counts and Recall for each row, and
 #' marginal counts, Precission and class F-measure for each column. The 3x2
 #' subset of cells at the bottom right show (in this order): the overall
@@ -492,23 +496,23 @@ setMethod("chkp",signature(obj="binClst"),function(obj,ctrlLbls=NULL,ctrlClrs=NU
 #' overall value of the Macro-F-Measure is an average of the class F-measure
 #' values, hence it is underestimated if the number of classes is lower than the
 #' number of clusters.
-#' 
+#'
 #' If \code{obj} is a \link{binClstPath_instance} and there is a column "lbl" in
 #' the obj@@pth slot with an expert labelling, this labelling will be used by
 #' default.
-#' 
+#'
 #' If \code{obj} is a \code{binClstStck} instance and, for all paths in the
 #' stack, there is a column "lbl" in the obj@@pth slot of each, this labelling
 #' will be used to compute the confusion matrix for the whole stack.
-#' 
+#'
 #' If \code{obj} and \code{ref} are both a \link{binClst_instance} (e.g.
 #' smoothed versus non-smoothed), the confusion matrix compares both labellings.
-#' 
+#'
 #' @return If ret=TRUE returns a matrix with the confusion matrix values.
-#'   
+#'
 #' @export
 #' @rdname cnfm
-#'   
+#'
 #' @examples
 #' # -- apply EMbC to the example path --
 #' mybcp <- stbc(expth,info=-1)
@@ -567,7 +571,7 @@ setMethod("cnfm",signature(obj="binClst",ref="numeric"),function(obj,ref,ret=FAL
 	colnames(cMtx) <- c(paste('cls.',formatC(1:bC@k,width=2,format='d',flag='0'),sep=''),'  mrg.','  Prc.')
 	if (ret) return(cMtx)
 	})
-	
+
 #' @rdname cnfm
 setMethod("cnfm",signature(obj="binClstPath",ref="missing"),function(obj,ref,ret=FALSE,...){
 	if ('lbl' %in% names(obj@pth))
@@ -575,7 +579,7 @@ setMethod("cnfm",signature(obj="binClstPath",ref="missing"),function(obj,ref,ret
 	else
 		cat(paste('Error: no reference labels for ',deparse(substitute(obj)),'\n',sep=''))
 	})
-	
+
 #' @rdname cnfm
 setMethod("cnfm",signature(obj="binClstStck",ref="missing"),function(obj,ref,ret=FALSE,...){
 	if (all(unlist(lapply(obj@bCS,function(bci) (class(bci)=='binClstPath' && 'lbl' %in% names(bci@pth))))))
@@ -583,7 +587,7 @@ setMethod("cnfm",signature(obj="binClstStck",ref="missing"),function(obj,ref,ret
 	else
 		cat(paste('Error: no reference labels for ',deparse(substitute(obj)),'\n',sep=''))
 	})
-	
+
 #' @rdname cnfm
 setMethod("cnfm",signature(obj="binClst",ref="binClst"),function(obj,ref,ret=FALSE,...){
 	if (length(obj@A)==length(ref@A))
@@ -593,22 +597,22 @@ setMethod("cnfm",signature(obj="binClst",ref="binClst"),function(obj,ref,ret=FAL
 	})
 
 #' @title Posterior smoothing of single local labels.
-#'   
+#'
 #' @description \code{smth} Performs a posterior smoothing of single local
 #'   labels (locations that differ from their neighbouring locations while the
 #'   later have equal labels).
-#'   
+#'
 #' @param obj A \code{binClst_instance}.
-#'   
+#'
 #' @param dlta A numeric value in the range (0,1) (default is 1) indicating the
 #'   user's will to accept a change of label. The change of label is done
 #'   whenever the decrease in likelihood is not greater then \code{dlta}.
-#'   
+#'
 #' @return A smoothed copy of the input instance.
-#'   
+#'
 #' @export
 #' @rdname smth
-#'   
+#'
 #' @examples
 #' # -- cluster the example path with a prior smooth of 1 hour --
 #' mysmoothbcp <- stbc(expth,smth=1,info=-1)
@@ -623,44 +627,44 @@ setMethod("smth",signature(obj="binClst"),function(obj,dlta=1){
 		return(postSmth(obj,dlta))})
 
 #' @title Manual relabelling of clusters.
-#'   
+#'
 #' @description \code{rlbl} Manual relabelling of clusters (to merge clusters or
 #'   relabel merged clusters).
-#'   
+#'
 #' @param obj A \link{binClst_instance}.
-#'   
+#'
 #' @param old The number of the cluster to be relabelled.
-#'   
+#'
 #' @param new The new number of the cluster.
-#'   
+#'
 #' @param reset A boolean value (defaults to FALSE). If reset=TRUE the labelling
 #'   is reset to the original state.
-#'   
+#'
 #' @details
-#' 
-#' Whenever two adjacent clusters are merged, the label identifying the 
-#' splitting variable between them both is meaningless, and the algorithm ends 
-#' up assigning either a L or H only depending on how it evolved until reaching 
-#' the merging point. Thus it can happen that the final labelling of the 
-#' resulting cluster is not the most intuitive one. With this method the labels 
+#'
+#' Whenever two adjacent clusters are merged, the label identifying the
+#' splitting variable between them both is meaningless, and the algorithm ends
+#' up assigning either a L or H only depending on how it evolved until reaching
+#' the merging point. Thus it can happen that the final labelling of the
+#' resulting cluster is not the most intuitive one. With this method the labels
 #' can be changed as desired. It can also be used to manually force the merging
 #' of two clusters.
-#' 
-#' This method does not return a rellabeled copy of the input \code{obj}, 
-#' instead the \link{binClst_instance} itself is relabelled. However, this is 
+#'
+#' This method does not return a rellabeled copy of the input \code{obj},
+#' instead the \link{binClst_instance} itself is relabelled. However, this is
 #' intended only for output and visualization pourposes (sctr(), lblp(),
 #' cnfm(), view()) as the \link{binClst_instance} parameters (GMM parameters and
-#' binary delimiters) are not recomputed. Thus the input instance can always be 
+#' binary delimiters) are not recomputed. Thus the input instance can always be
 #' reset to its original state.
-#' 
-#' @return This method does not return a rellabeled copy of the input 
+#'
+#' @return This method does not return a rellabeled copy of the input
 #'   \code{obj}, instead the \link{binClst_instance} itself is relabelled. It is
 #'   intended only for visualization pourposes, as it does not recompute the GMM
 #'   parameters nor the binary delimiters of the \link{binClst_instance}.
-#'   
+#'
 #' @export
 #' @rdname rlbl
-#'   
+#'
 #' @examples
 #' # -- apply EMbC to the example path --
 #' mybcp <- stbc(expth,info=-1)
@@ -684,33 +688,33 @@ setMethod("rlbl",signature(obj="binClst"),function(obj,old=0,new=0,reset=FALSE){
 		}
 	})
 
-	
+
 # binClstPath Methods
 # -------------------
 
 #' @title Variables' profile plots
-#'   
-#' @description \code{varp} easy plot of input, output and intermediate 
+#'
+#' @description \code{varp} easy plot of input, output and intermediate
 #'   variables of a \link{binClstPath_instance}.
-#'   
+#'
 #' @param obj Either a matrix or a  \link{binClstPath_instance}.
-#'   
+#'
 #' @param lims A numeric vector with lower and upper bounds to limit the plot.
-#'   
+#'
 #' @param ... Parameter \code{lims} is optional.
-#'   
+#'
 #' @details
-#' 
-#' If \code{obj} is a matrix, axes labels are automatically generated from the 
+#'
+#' If \code{obj} is a matrix, axes labels are automatically generated from the
 #' \code{colnames()} of the matrix, hence they can be changed as desired.
-#' 
-#' If \code{obj} is a \link{binClstPath_instance} it plots the values of the 
-#' intermediate computations saved in slots mybcp@@spn (span times), mybcp@@dst 
+#'
+#' If \code{obj} is a \link{binClstPath_instance} it plots the values of the
+#' intermediate computations saved in slots mybcp@@spn (span times), mybcp@@dst
 #' (distances) and mybcp@@hdg (local heading directions).
-#' 
+#'
 #' @export
 #' @rdname varp
-#'   
+#'
 #' @examples
 #' # -- apply EMbC to the example path --
 #' mybcp <- stbc(expth,info=-1)
@@ -753,24 +757,25 @@ setMethod("varp",signature(obj="matrix"),function(obj,lims=NULL,...){
 # --------------------------
 
 #' @title Path fast view
-#'   
+#'
 #' @description \code{view} provides a fast plot of a segmented trajectory or
 #'   specific chunks of it.
-#'   
+#'
 #' @param obj A \link{binClstPath_instance} or a data.frame with the format
 #'   described for slot \code{binClstPath@@pth}.
-#'   
+#'
 #' @param lbl A numeric vector with location labels. If \code{obj} is a
 #'   \link{binClstPath_instance} the clustering labels are used by default.
-#'   
+#'
 #' @param lims A numeric vector with lower and upper limit locations to show
 #'   only a chunk of the trajectory.
-#'   
+#' @param bg A valid colour especification to be used as background colour. By default a light-grey colour is used to enhance data points visibility.
+#'
 #' @param ... Parameters \code{lbl} and \code{lims} are optional.
-#'   
+#'
 #' @export
 #' @rdname view
-#'   
+#'
 #' @examples
 #' # -- Fast view of the binClstPath instance included in the package --
 #' view(expth)
@@ -780,26 +785,29 @@ setMethod("varp",signature(obj="matrix"),function(obj,lims=NULL,...){
 setGeneric("view",function(obj,...){standardGeneric("view")})
 
 #' @rdname view
-setMethod("view",signature(obj="binClstPath"),function(obj,lbl=NULL,lims=NULL,...){
-	parDef <- parSet(mtx=matrix(c(1,2),2,1),heights=c(0.2,1),bg=brewer.pal(8,'Greys')[4])
+setMethod("view",signature(obj="binClstPath"),function(obj, lbl=NULL, lims=NULL, bg=NULL, ...){
+	if (is.null(bg)) bg <- brewer.pal(8,'Greys')[4]
+	parDef <- parSet(mtx=matrix(c(1,2),2,1), heights=c(0.2,1), bg=bg)
 	if (is.numeric(lbl) && (length(lbl)>0)) pal <- getColors(length(table(lbl)))
 	else {lbl <- obj@A; pal <- obj@C}
 	if (is.numeric(lims) && (length(lims)==2)) {a <- max(1,lims[1]); b <- min(lims[2],obj@n)}
 	else {a <- 1; b <- obj@n}
 	par(mar=c(1,4,1,1))
-	plot(1,1,xlab='',ylab='',xlim=c(a,b),ylim=c(0,1),xaxt="n",yaxt="n",bty="n",type="n")
-	rect(seq(a,b-1),0,seq(a+1,b),1,col=pal[lbl[a:b]],border=NA)
+	plot(1, 1, xlab='', ylab='', xlim=c(a,b), ylim=c(0,1), xaxt="n", yaxt="n", bty="n", type="n")
+	rect(seq(a,b-1), 0, seq(a+1,b), 1, col=pal[lbl[a:b]], border=NA)
 	par(mar=c(4,4,1,1))
-	plot(1,1,xlab='lon',ylab='lat',xlim=c(min(obj@pth$lon[a:b]),max(obj@pth$lon[a:b])),ylim=c(min(obj@pth$lat[a:b]),max(obj@pth$lat[a:b])),type="n")
-	points(obj@pth$lon[a:b],obj@pth$lat[a:b],col=pal[lbl[a:b]],pch=20)
-	lines(obj@pth$lon[a:b],obj@pth$lat[a:b],col=pal[length(pal)])
-#  	world(xlim=c(min(obj@pth$lon),max(obj@pth$lon)),ylim=c(min(obj@pth$lat),max(obj@pth$lat)))
+	plims <- getPropLims(obj@pth, a, b)
+	plot(1, 1, xlab='lon', ylab='lat', xlim=plims$x, ylim=plims$y, type="n", asp=1)
+	points(obj@pth$lon[a:b], obj@pth$lat[a:b], col=pal[lbl[a:b]], pch=20)
+	lines(obj@pth$lon[a:b], obj@pth$lat[a:b], col=pal[length(pal)])
+#  	world(xlim=plims$x, ylim=plims$y)
  	par(parDef)
 	})
 
 #' @rdname view
-setMethod("view",signature(obj="data.frame"),function(obj,lbl=NULL,lims=NULL,...){
-	parDef <- parSet(mtx=matrix(c(1,2),2,1),heights=c(0.2,1),bg=brewer.pal(8,'Greys')[4])
+setMethod("view",signature(obj="data.frame"),function(obj, lbl=NULL, lims=NULL, bg=NULL, ...){
+	if (is.null(bg)) bg <- brewer.pal(8,'Greys')[4]
+	parDef <- parSet(mtx=matrix(c(1,2),2,1), heights=c(0.2,1), bg=bg)
 	colnames(obj)[c(1,2,3)] <- c('dTm','lon','lat')
 	if (!(is.numeric(lbl) && (length(lbl)>0))){
 		if ('lbl' %in% names(obj)) lbl <- obj$lbl
@@ -809,48 +817,48 @@ setMethod("view",signature(obj="data.frame"),function(obj,lbl=NULL,lims=NULL,...
 	if (is.numeric(lims) && (length(lims)==2)) {a <- max(1,lims[1]); b <- min(lims[2],obj@n)}
 	else {a <- 1; b <- nrow(obj)}
 	par(mar=c(1,4,1,1))
-	plot(1,1,xlab='',ylab='',xlim=c(a,b),ylim=c(0,1),xaxt="n",yaxt="n",bty="n",type="n")
-	rect(seq(a,b-1),0,seq(a+1,b),1,col=pal[lbl[a:b]],border=NA)
+	plot(1, 1, xlab='', ylab='', xlim=c(a,b), ylim=c(0,1), xaxt="n", yaxt="n", bty="n", type="n")
+	rect(seq(a,b-1), 0, seq(a+1,b), 1, col=pal[lbl[a:b]], border=NA)
 	par(mar=c(4,4,1,1))
-	plot(1,1,xlab='lon',ylab='lat',xlim=c(min(obj$lon[a:b]),max(obj$lon[a:b])),ylim=c(min(obj$lat[a:b]),max(obj$lat[a:b])),type="n")
-	points(obj$lon[a:b],obj$lat[a:b],col=pal[lbl[a:b]],pch=20)
-	lines(obj$lon[a:b],obj$lat[a:b],col=pal[length(pal)])
-#  	world(xlim=c(min(obj$lon),max(obj$lon)),ylim=c(min(obj$lat),max(obj$lat)))
+	plims <- getPropLims(obj, a, b)
+	plot(1, 1, xlab='lon', ylab='lat', xlim=plims$x, ylim=plims$y, type="n", asp=1)
+	points(obj$lon[a:b], obj$lat[a:b], col=pal[lbl[a:b]], pch=20)
+	lines(obj$lon[a:b], obj$lat[a:b], col=pal[length(pal)])
  	par(parDef)
 	})
 
 #' @title Generate a pointwise .kml file of a \link{binClstPath_instance}
-#'   
+#'
 #' @description \code{pkml} generates a pointwise KML file of a
 #'   \link{binClstPath_instance}, which can be viewed using Google Earth or
 #'   other GIS software.
-#'   
+#'
 #' @param obj A \link{binClstPath_instance}.
-#'   
+#'
 #' @param folder A character string indicating the name of the folder in which
 #'   the .kml file will be saved. If the folder does not exist it is
 #'   automatically created, (defaults to '~/embcDocs').
-#'   
+#'
 #' @param markerRadius A numeric value indicating the radius of the markers to
 #'   be plotted, (defaults to 5 pixels).
-#'   
+#'
 #' @param display A boolean value (defaults to FALSE) to automatically launch
 #'   Google-Earth from within R to visualize the generated .kml document.
 #'   (Google Earth must already be installed on the system. In Windows, it must
 #'   be associated with the .kml file type.)
-#'   
+#'
 #' @param showClst A numeric vector indicating a subset of clusters to be shown.
-#'   
+#'
 #' @param ... Parameters \code{folder}, \code{markerRadius}, \code{display} and
 #'   \code{showClst} are optional.
-#'   
+#'
 #' @return The path/name of the saved kml file.
-#'   
+#'
 #' @seealso \code{\link{bkml}}
-#'   
+#'
 #' @export
 #' @rdname pkml
-#'   
+#'
 #' @examples
 #' \dontrun{
 #' # -- apply EMbC to the example path --
@@ -877,39 +885,39 @@ setMethod("pkml",signature(obj="binClstPath"),
 			  google <- c('/usr/bin/google-earth','/usr/bin/googleearth')
 				system(paste(google[which(file.exists(google))],kmlD@fName,'&',sep=" "),ignore.stdout=TRUE,ignore.stderr=TRUE)
 			  }
-		}	
+		}
 	return(cat('saved file ',kmlD@fName,'\n'))
 	})
 
 
 #' @title Generate a burstwise .kml file of a \link{binClstPath_instance}.
-#'   
+#'
 #' @description \code{bkml} generates a burstwise .kml file of a
 #'   \link{binClstPath_instance}, which can be viewed using Google Earth or
 #'   other GIS software. At first issue, this command can take some time because
 #'   bursted segmentation has to be computed.
-#'   
+#'
 #' @param obj A \link{binClstPath_instance}.
-#'   
+#'
 #' @param folder A character string indicating the name of the folder in which
 #'   the .kml file will be saved. If the folder does not exist it is
 #'   automatically created, (defaults to '~/embcDocs').
-#'   
+#'
 #' @param markerRadius A numeric value indicating the radius of the markers to
 #'   be plotted, (defaults to 5 pixels).
-#'   
+#'
 #' @param display A boolean value (defaults to FALSE) to automatically launch
 #'   Google-Earth from within R to visualize the generated .kml document.
 #'   (Google Earth must already be installed on the system. In Windows, it must
 #'   be associated with the .kml file type.)
-#'   
+#'
 #' @return The path/name of the saved kml file.
-#'   
+#'
 #' @seealso \code{\link{pkml}}
-#'   
+#'
 #' @export
 #' @rdname bkml
-#'   
+#'
 #' @examples
 #' \dontrun{
 #' # -- apply EMbC to the example path --
@@ -934,46 +942,46 @@ setMethod("bkml",signature(obj="binClstPath"),
 		    google <- c('/usr/bin/google-earth','/usr/bin/googleearth')
 		    system(paste(google[which(file.exists(google))],kmlD@fName,'&',sep=" "),ignore.stdout=TRUE,ignore.stderr=TRUE)
 		  }
-		}	
+		}
 	return(cat('saved file ',kmlD@fName,'\n'))
 	})
 
 #' @title Generate an HTML pointwise webmap of a \link{binClstPath_instance}.
-#'   
+#'
 #' @description \code{pmap} generates a pointwise .html file-map of a
 #'   \link{binClstPath_instance} in HTML5, using Google Maps JavaScript API v3
 #'   (\url{https://developers.google.com/maps/documentation/javascript/}). The
 #'   resulting file can be viewed locally in most browsers (an internet
 #'   connection is required for displaying the map tiles) or posted online.
-#'   
+#'
 #' @param obj A \link{binClstPath_instance}.
-#'   
-#' @param folder A character string indicating the name of the folder in which 
-#'   the .html file will be saved. If the folder does not exist it is 
+#'
+#' @param folder A character string indicating the name of the folder in which
+#'   the .html file will be saved. If the folder does not exist it is
 #'   automatically created, (defaults to '~/embcDocs').
-#'   
-#' @param apiKey A character string specifying the API Key to be passed to the 
-#'   Google Maps server. No Key is needed for using Google Maps JavaScript API 
-#'   v3, but users may wish to specify a key in order to monitor web traffic if 
+#'
+#' @param apiKey A character string specifying the API Key to be passed to the
+#'   Google Maps server. No Key is needed for using Google Maps JavaScript API
+#'   v3, but users may wish to specify a key in order to monitor web traffic if
 #'   the document is being posted online.
-#'   
-#' @param mapType A character string specifying the type of map to be used in 
-#'   the background. This value is passed directly to the Google Maps server, 
-#'   and currently can be set to ROADMAP, SATELLITE, HYBRID, or TERRAIN. (See 
+#'
+#' @param mapType A character string specifying the type of map to be used in
+#'   the background. This value is passed directly to the Google Maps server,
+#'   and currently can be set to ROADMAP, SATELLITE, HYBRID, or TERRAIN. (See
 #'   the Google Maps API documentation for more information.)
-#'   
-#' @param markerRadius A numeric value indicating the radius of the markers to 
+#'
+#' @param markerRadius A numeric value indicating the radius of the markers to
 #'   be plotted, (defaults to 5 pixels).
-#'   
-#' @param display A boolean value (defaults to FALSE) to automatically launch 
-#'   the system's default browser from witin R to visualize the generated .html 
+#'
+#' @param display A boolean value (defaults to FALSE) to automatically launch
+#'   the system's default browser from witin R to visualize the generated .html
 #'   document.
-#'   
+#'
 #' @return The path/name of the saved html file.
-#'   
+#'
 #' @export
 #' @rdname pmap
-#'   
+#'
 #' @examples
 #' \dontrun{
 #' # -- apply EMbC to the example path --
@@ -994,20 +1002,20 @@ setMethod("pmap",signature(obj="binClstPath"),
             return(cat('saved file ',wMap@fName,'\n'))})
 
 #' @title Generate an HTML burstwise webmap of a \link{binClstPath_instance}.
-#'   
+#'
 #' @description \code{bmap} generates a burstwise .html file map of a
 #'   \link{binClstPath_instance} in HTML5, using Google Maps JavaScript API v3
 #'   (\url{https://developers.google.com/maps/documentation/javascript/}). The
 #'   resulting file can be viewed locally in most browsers (an internet
 #'   connection is required for displaying the map tiles) or posted online.
-#'   
+#'
 #' @inheritParams pmap
-#'   
+#'
 #' @return The path/name of the saved .html file.
-#'   
+#'
 #' @export
 #' @rdname bmap
-#'   
+#'
 #' @examples
 #' \dontrun{
 #' # -- apply EMbC to the example path --
